==> rapid_widgets_library-0.1.4.tar.gz: lib/custom-solid-card.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';

Widget customSolidCard(MaterialCardData data, Function(String, int) callback) {
  return Container(
    decoration: BoxDecoration(
      image: DecorationImage(
        image: NetworkImage((data.imgPath != null)
            ? data.imgPath
            : 'http://104.40.75.137:9003/assets/cms/image5.png'),
        fit: BoxFit.cover,
      ),
      boxShadow: <BoxShadow>[
        BoxShadow(
          color: Color(0xff00002e),
          offset: Offset(0.0, 2.0),
          blurRadius: 6.0,
        ),
      ],
      color: Colors.white,
      borderRadius: BorderRadius.circular(5),
      border: Border.all(
        color: Color(0x00000029),
        width: 1,
      ),
    ),
    height: (data.imgHeight != null) ? data.imgHeight : 145,
    width: (data.imgWidth != null) ? data.imgWidth : 145,
    child: Padding(
      padding: const EdgeInsets.only(left: 84.0, top: 46, bottom: 46),
      child: Container(
        decoration: BoxDecoration(
            color: (data.containerbgColor != null)
                ? data.containerbgColor
                : Color(0xffFEF5BB),
            borderRadius: BorderRadius.only(
                topLeft: Radius.circular(5.0),
                bottomLeft: Radius.circular(5.0))),
        width: (data.containerWidth != null) ? data.containerWidth : 61,
        height: (data.containerHeight != null) ? data.containerHeight : 53,
        child: Padding(
          padding: const EdgeInsets.only(
              left: 28.0, right: 9, top: 15.0, bottom: 16.0),
          child: Text(
            (data.title != null) ? data.title : '04',
            style: TextStyle(
                fontSize: 16, fontFamily: 'Georgia', color: Color(0xff707070)),
          ),
        ),
      ),
    ),
  );
}

==> rapid_widgets_library-0.2.9.tar.gz: lib/custom-solid-card.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';

Widget customSolidCard(MaterialCardData data, Function(String, int) callback) {
  return Container(
    decoration: BoxDecoration(
      image: DecorationImage(
        image: NetworkImage((data.imgPath != null)
            ? data.imgPath
            : 'http://104.40.75.137:9003/assets/cms/image5.png'),
        fit: BoxFit.cover,
      ),
      boxShadow: <BoxShadow>[
        BoxShadow(
          color: Color(0xff00002e),
          offset: Offset(0.0, 2.0),
          blurRadius: 6.0,
        ),
      ],
      color: Colors.white,
      borderRadius: BorderRadius.circular(5),
      border: Border.all(
        color: Color(0x00000029),
        width: 1,
      ),
    ),
    height: (data.imgHeight != null) ? data.imgHeight : 145,
    width: (data.imgWidth != null) ? data.imgWidth : 145,
    child: Padding(
      padding: const EdgeInsets.only(left: 10.0, top: 46, bottom: 46),
      child: Container(
        decoration: BoxDecoration(
            color: (data.containerbgColor != null)
                ? data.containerbgColor
                : Color(0xffFEF5BB),
            borderRadius: BorderRadius.only(
                topLeft: Radius.circular(5.0),
                bottomLeft: Radius.circular(5.0))),
        width: (data.containerWidth != null) ? data.containerWidth : 135,
        height: (data.containerHeight != null) ? data.containerHeight : 53,
        child: Padding(
          padding: const EdgeInsets.only(
              left: 28.0, right: 9, top: 15.0, bottom: 16.0),
          child: Text(
            (data.title != null) ? data.title : '04',
            style: TextStyle(
                fontSize: 20, fontFamily: 'Segoe UI', color: Color(0xff707070)),
          ),
        ),
      ),
    ),
  );
}
